@@ -16,7 +16,7 @@ class MainConfig:
     SaveCoTToDB = bool(False)
 
     # this should be set before startup
-    DBFilePath = str(currentPath + r'\FTSDataBase.db')
+    DBFilePath = str(r'~/FTSDataBase.db')
 
     # the version information of the server (recommended to leave as default)
     version = 'FreeTAKServer-1.1.1'
