@@ -1,5 +1,3 @@
-import eventlet
-eventlet.monkey_patch(thread=False)
 from flask import Flask, request, jsonify
 from flask_sqlalchemy import SQLAlchemy
 from flask_socketio import SocketIO, emit
@@ -41,7 +39,7 @@ app.config['SQLALCHEMY_TRACK_MODIFICATIONS'] = False
 db = SQLAlchemy(app)
 dbController.session = db.session
 CORS(app)
-socketio = SocketIO(app, async_handlers=True, async_mode="eventlet")
+socketio = SocketIO(app, async_handlers=True, async_mode="threading")
 socketio.init_app(app, cors_allowed_origins="*")
 APIPipe = None
 CommandPipe = None
@@ -262,7 +260,7 @@ class RestAPI:
 
         socketio.run(app, host=IP, port=Port)
         # try below if something breaks
-        # socketio.run(app, host=IP, port=Port, debug=True, use_reloader=False)
+        # socketio.run(app, host='0.0.0.0', port=10984, debug=True, use_reloader=False)
 
 
     def serializeJsonToModel(self, model, Json):
